Python: module src.na

src.na (28 February 2006) | index /Users/d3y382/workspaces/apbs-pdb2pqr/pdb2pqr/src/na.py

`Nucleic Acid Structures for PDB2PQR
This module contains the base nucleic acid structures for
pdb2pqr.
----------------------------
PDB2PQR -- An automated pipeline for the setup, execution, and analysis of
Poisson-Boltzmann electrostatics calculations
Copyright (c) 2002-2011, Jens Erik Nielsen, University College Dublin;
Nathan A. Baker, Battelle Memorial Institute, Developed at the Pacific
Northwest National Laboratory, operated by Battelle Memorial Institute,
Pacific Northwest Division for the U.S. Department Energy.;
Paul Czodrowski & Gerhard Klebe, University of Marburg.
All rights reserved.
Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
* Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.
* Neither the names of University College Dublin, Battelle Memorial Institute,
Pacific Northwest National Laboratory, US Department of Energy, or University
of Marburg nor the names of its contributors may be used to endorse or promote
products derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
OF THE POSSIBILITY OF SUCH DAMAGE.
----------------------------`

Modules
`` |  |
copy math | os string | sys |

Classes
`` |  | src.structures.Residue Nucleic ADE RA CYT RC GUA RG THY DT URA RU
class ADE(Nucleic)
`` | `Adenosine class This class gives data about the Adenosine object, and inherits off the base residue class.`
| Method resolution order: ADE Nucleic src.structures.Residue Methods defined here: __init__(self, atoms, ref) `Initialize the class Parameters atoms: A list of Atom objects to be stored in this class (list)` letterCode(self) setState(self) `Set the state to distinguish RNA from DNA.` Methods inherited from Nucleic: addAtom(self, atom) `Override the existing addAtom - include the link to the reference object` addDihedralAngle(self, value) `Add the value to the list of chiangles Parameters value: The value to be added (float)` createAtom(self, atomname, newcoords) `Create an atom. Overrides the generic residue's createAtom(). Parameters atomname: The name of the atom to add (string) newcoords: The coordinates of the atom (list)` Methods inherited from src.structures.Residue: __str__(self) `Basic string representation` addMissing(self, value) `Add the value to the list of missing atoms Parameters value: The name of the missing atom (string)` get(self, name) `Get a member of the Residue class Parameters name: The name of the member (string) Possible Values atoms: The atoms in the residue name: The name of the residue chainID: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise missing: List of missing atoms of the residue Returns item: The value of the member` getAtom(self, name) `Retrieve an atom from the mapping Parameters resname: The name of the residue to retrieve (string)` getAtoms(self) getCharge(self) `Get the total charge of the residue. In order to get rid of floating point rounding error, do the string transformation. Returns: charge: The charge of the residue (float)` hasAtom(self, name) numAtoms(self) `Get the number of atoms for the residue Returns Number of atoms in the residue (int)` removeAtom(self, atomname) `Remove an atom from the residue object. Parameters atomname: The name of the atom to be removed (string)` renameAtom(self, oldname, newname) `Rename an atom to a new name Parameters oldname: The old atom name (string) newname: The new atom name (string)` renameResidue(self, name) `Rename a given residue Parameters name: The new name of the residue` reorder(self) `Reorder the atoms to start with N, CA, C, O if they exist` rotateTetrahedral(self, atom1, atom2, angle) `Rotate about the atom1-atom2 bond by a given angle All atoms connected to atom2 will rotate. Parameters: atom1: The first atom of the bond to rotate about (atom) atom2: The second atom of the bond to rotate about (atom) angle: The number of degrees to rotate (float)` set(self, name, value) `Set a member of the Residue class to a specific value Parameters name: The name of the object to set (string) value: The object to append Possible Values atoms: The atoms in the residue name: The name of the residue chain: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise isDirty: 1 if the residue is not missing atoms, 0 otherwise Notes resSeq points to the residue.setResSeq function Returns item: The value of the member` setChainID(self, value) `Set the chainID field to a certain value` setDonorsAndAcceptors(self) `Set the donors and acceptors within the residue` setResSeq(self, value) `Set the atom field resSeq to a certain value and change the residue's information. The icode field is no longer useful. Parameters value: The new value of resSeq (int)` update_terminus_status(self) `Update the isNterms and isCterm flags`
class CYT(Nucleic)
`` | `Cytidine class This class gives data about the Cytidine object, and inherits off the base residue class.`
| Method resolution order: CYT Nucleic src.structures.Residue Methods defined here: __init__(self, atoms, ref) `Initialize the class Parameters atoms: A list of Atom objects to be stored in this class (list)` letterCode(self) setState(self) `Set the state to distinguish RNA from DNA.` Methods inherited from Nucleic: addAtom(self, atom) `Override the existing addAtom - include the link to the reference object` addDihedralAngle(self, value) `Add the value to the list of chiangles Parameters value: The value to be added (float)` createAtom(self, atomname, newcoords) `Create an atom. Overrides the generic residue's createAtom(). Parameters atomname: The name of the atom to add (string) newcoords: The coordinates of the atom (list)` Methods inherited from src.structures.Residue: __str__(self) `Basic string representation` addMissing(self, value) `Add the value to the list of missing atoms Parameters value: The name of the missing atom (string)` get(self, name) `Get a member of the Residue class Parameters name: The name of the member (string) Possible Values atoms: The atoms in the residue name: The name of the residue chainID: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise missing: List of missing atoms of the residue Returns item: The value of the member` getAtom(self, name) `Retrieve an atom from the mapping Parameters resname: The name of the residue to retrieve (string)` getAtoms(self) getCharge(self) `Get the total charge of the residue. In order to get rid of floating point rounding error, do the string transformation. Returns: charge: The charge of the residue (float)` hasAtom(self, name) numAtoms(self) `Get the number of atoms for the residue Returns Number of atoms in the residue (int)` removeAtom(self, atomname) `Remove an atom from the residue object. Parameters atomname: The name of the atom to be removed (string)` renameAtom(self, oldname, newname) `Rename an atom to a new name Parameters oldname: The old atom name (string) newname: The new atom name (string)` renameResidue(self, name) `Rename a given residue Parameters name: The new name of the residue` reorder(self) `Reorder the atoms to start with N, CA, C, O if they exist` rotateTetrahedral(self, atom1, atom2, angle) `Rotate about the atom1-atom2 bond by a given angle All atoms connected to atom2 will rotate. Parameters: atom1: The first atom of the bond to rotate about (atom) atom2: The second atom of the bond to rotate about (atom) angle: The number of degrees to rotate (float)` set(self, name, value) `Set a member of the Residue class to a specific value Parameters name: The name of the object to set (string) value: The object to append Possible Values atoms: The atoms in the residue name: The name of the residue chain: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise isDirty: 1 if the residue is not missing atoms, 0 otherwise Notes resSeq points to the residue.setResSeq function Returns item: The value of the member` setChainID(self, value) `Set the chainID field to a certain value` setDonorsAndAcceptors(self) `Set the donors and acceptors within the residue` setResSeq(self, value) `Set the atom field resSeq to a certain value and change the residue's information. The icode field is no longer useful. Parameters value: The new value of resSeq (int)` update_terminus_status(self) `Update the isNterms and isCterm flags`
class DT(THY)
`` |  | Method resolution order: DT THY Nucleic src.structures.Residue Methods inherited from THY: __init__(self, atoms, ref) `Initialize the class Parameters atoms: A list of Atom objects to be stored in this class (list)` letterCode(self) setState(self) `Set the state to distinguish RNA from DNA. In this case it is always DNA.` Methods inherited from Nucleic: addAtom(self, atom) `Override the existing addAtom - include the link to the reference object` addDihedralAngle(self, value) `Add the value to the list of chiangles Parameters value: The value to be added (float)` createAtom(self, atomname, newcoords) `Create an atom. Overrides the generic residue's createAtom(). Parameters atomname: The name of the atom to add (string) newcoords: The coordinates of the atom (list)` Methods inherited from src.structures.Residue: __str__(self) `Basic string representation` addMissing(self, value) `Add the value to the list of missing atoms Parameters value: The name of the missing atom (string)` get(self, name) `Get a member of the Residue class Parameters name: The name of the member (string) Possible Values atoms: The atoms in the residue name: The name of the residue chainID: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise missing: List of missing atoms of the residue Returns item: The value of the member` getAtom(self, name) `Retrieve an atom from the mapping Parameters resname: The name of the residue to retrieve (string)` getAtoms(self) getCharge(self) `Get the total charge of the residue. In order to get rid of floating point rounding error, do the string transformation. Returns: charge: The charge of the residue (float)` hasAtom(self, name) numAtoms(self) `Get the number of atoms for the residue Returns Number of atoms in the residue (int)` removeAtom(self, atomname) `Remove an atom from the residue object. Parameters atomname: The name of the atom to be removed (string)` renameAtom(self, oldname, newname) `Rename an atom to a new name Parameters oldname: The old atom name (string) newname: The new atom name (string)` renameResidue(self, name) `Rename a given residue Parameters name: The new name of the residue` reorder(self) `Reorder the atoms to start with N, CA, C, O if they exist` rotateTetrahedral(self, atom1, atom2, angle) `Rotate about the atom1-atom2 bond by a given angle All atoms connected to atom2 will rotate. Parameters: atom1: The first atom of the bond to rotate about (atom) atom2: The second atom of the bond to rotate about (atom) angle: The number of degrees to rotate (float)` set(self, name, value) `Set a member of the Residue class to a specific value Parameters name: The name of the object to set (string) value: The object to append Possible Values atoms: The atoms in the residue name: The name of the residue chain: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise isDirty: 1 if the residue is not missing atoms, 0 otherwise Notes resSeq points to the residue.setResSeq function Returns item: The value of the member` setChainID(self, value) `Set the chainID field to a certain value` setDonorsAndAcceptors(self) `Set the donors and acceptors within the residue` setResSeq(self, value) `Set the atom field resSeq to a certain value and change the residue's information. The icode field is no longer useful. Parameters value: The new value of resSeq (int)` update_terminus_status(self) `Update the isNterms and isCterm flags`
class GUA(Nucleic)
`` | `Guanosine class This class gives data about the Guanosine object, and inherits off the base residue class.`
| Method resolution order: GUA Nucleic src.structures.Residue Methods defined here: __init__(self, atoms, ref) `Initialize the class Parameters atoms: A list of Atom objects to be stored in this class (list)` letterCode(self) setState(self) `Set the state to distinguish RNA from DNA.` Methods inherited from Nucleic: addAtom(self, atom) `Override the existing addAtom - include the link to the reference object` addDihedralAngle(self, value) `Add the value to the list of chiangles Parameters value: The value to be added (float)` createAtom(self, atomname, newcoords) `Create an atom. Overrides the generic residue's createAtom(). Parameters atomname: The name of the atom to add (string) newcoords: The coordinates of the atom (list)` Methods inherited from src.structures.Residue: __str__(self) `Basic string representation` addMissing(self, value) `Add the value to the list of missing atoms Parameters value: The name of the missing atom (string)` get(self, name) `Get a member of the Residue class Parameters name: The name of the member (string) Possible Values atoms: The atoms in the residue name: The name of the residue chainID: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise missing: List of missing atoms of the residue Returns item: The value of the member` getAtom(self, name) `Retrieve an atom from the mapping Parameters resname: The name of the residue to retrieve (string)` getAtoms(self) getCharge(self) `Get the total charge of the residue. In order to get rid of floating point rounding error, do the string transformation. Returns: charge: The charge of the residue (float)` hasAtom(self, name) numAtoms(self) `Get the number of atoms for the residue Returns Number of atoms in the residue (int)` removeAtom(self, atomname) `Remove an atom from the residue object. Parameters atomname: The name of the atom to be removed (string)` renameAtom(self, oldname, newname) `Rename an atom to a new name Parameters oldname: The old atom name (string) newname: The new atom name (string)` renameResidue(self, name) `Rename a given residue Parameters name: The new name of the residue` reorder(self) `Reorder the atoms to start with N, CA, C, O if they exist` rotateTetrahedral(self, atom1, atom2, angle) `Rotate about the atom1-atom2 bond by a given angle All atoms connected to atom2 will rotate. Parameters: atom1: The first atom of the bond to rotate about (atom) atom2: The second atom of the bond to rotate about (atom) angle: The number of degrees to rotate (float)` set(self, name, value) `Set a member of the Residue class to a specific value Parameters name: The name of the object to set (string) value: The object to append Possible Values atoms: The atoms in the residue name: The name of the residue chain: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise isDirty: 1 if the residue is not missing atoms, 0 otherwise Notes resSeq points to the residue.setResSeq function Returns item: The value of the member` setChainID(self, value) `Set the chainID field to a certain value` setDonorsAndAcceptors(self) `Set the donors and acceptors within the residue` setResSeq(self, value) `Set the atom field resSeq to a certain value and change the residue's information. The icode field is no longer useful. Parameters value: The new value of resSeq (int)` update_terminus_status(self) `Update the isNterms and isCterm flags`
class Nucleic(src.structures.Residue)
`` | `Nucleic class This class provides standard features of the nucleic acids listed below Parameters atoms: A list of Atom objects to be stored in this class (list) ref: The reference object for the amino acid. Used to convert from the alternate naming scheme to the main naming scheme.`
| Methods defined here: __init__(self, atoms, ref) addAtom(self, atom) `Override the existing addAtom - include the link to the reference object` addDihedralAngle(self, value) `Add the value to the list of chiangles Parameters value: The value to be added (float)` createAtom(self, atomname, newcoords) `Create an atom. Overrides the generic residue's createAtom(). Parameters atomname: The name of the atom to add (string) newcoords: The coordinates of the atom (list)` setState(self) `Adds the termini for all inherited objects` Methods inherited from src.structures.Residue: __str__(self) `Basic string representation` addMissing(self, value) `Add the value to the list of missing atoms Parameters value: The name of the missing atom (string)` get(self, name) `Get a member of the Residue class Parameters name: The name of the member (string) Possible Values atoms: The atoms in the residue name: The name of the residue chainID: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise missing: List of missing atoms of the residue Returns item: The value of the member` getAtom(self, name) `Retrieve an atom from the mapping Parameters resname: The name of the residue to retrieve (string)` getAtoms(self) getCharge(self) `Get the total charge of the residue. In order to get rid of floating point rounding error, do the string transformation. Returns: charge: The charge of the residue (float)` hasAtom(self, name) letterCode(self) numAtoms(self) `Get the number of atoms for the residue Returns Number of atoms in the residue (int)` removeAtom(self, atomname) `Remove an atom from the residue object. Parameters atomname: The name of the atom to be removed (string)` renameAtom(self, oldname, newname) `Rename an atom to a new name Parameters oldname: The old atom name (string) newname: The new atom name (string)` renameResidue(self, name) `Rename a given residue Parameters name: The new name of the residue` reorder(self) `Reorder the atoms to start with N, CA, C, O if they exist` rotateTetrahedral(self, atom1, atom2, angle) `Rotate about the atom1-atom2 bond by a given angle All atoms connected to atom2 will rotate. Parameters: atom1: The first atom of the bond to rotate about (atom) atom2: The second atom of the bond to rotate about (atom) angle: The number of degrees to rotate (float)` set(self, name, value) `Set a member of the Residue class to a specific value Parameters name: The name of the object to set (string) value: The object to append Possible Values atoms: The atoms in the residue name: The name of the residue chain: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise isDirty: 1 if the residue is not missing atoms, 0 otherwise Notes resSeq points to the residue.setResSeq function Returns item: The value of the member` setChainID(self, value) `Set the chainID field to a certain value` setDonorsAndAcceptors(self) `Set the donors and acceptors within the residue` setResSeq(self, value) `Set the atom field resSeq to a certain value and change the residue's information. The icode field is no longer useful. Parameters value: The new value of resSeq (int)` update_terminus_status(self) `Update the isNterms and isCterm flags`
class RA(ADE)
`` | `#Tie the class name to the base name in NA.XML`
| Method resolution order: RA ADE Nucleic src.structures.Residue Methods inherited from ADE: __init__(self, atoms, ref) `Initialize the class Parameters atoms: A list of Atom objects to be stored in this class (list)` letterCode(self) setState(self) `Set the state to distinguish RNA from DNA.` Methods inherited from Nucleic: addAtom(self, atom) `Override the existing addAtom - include the link to the reference object` addDihedralAngle(self, value) `Add the value to the list of chiangles Parameters value: The value to be added (float)` createAtom(self, atomname, newcoords) `Create an atom. Overrides the generic residue's createAtom(). Parameters atomname: The name of the atom to add (string) newcoords: The coordinates of the atom (list)` Methods inherited from src.structures.Residue: __str__(self) `Basic string representation` addMissing(self, value) `Add the value to the list of missing atoms Parameters value: The name of the missing atom (string)` get(self, name) `Get a member of the Residue class Parameters name: The name of the member (string) Possible Values atoms: The atoms in the residue name: The name of the residue chainID: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise missing: List of missing atoms of the residue Returns item: The value of the member` getAtom(self, name) `Retrieve an atom from the mapping Parameters resname: The name of the residue to retrieve (string)` getAtoms(self) getCharge(self) `Get the total charge of the residue. In order to get rid of floating point rounding error, do the string transformation. Returns: charge: The charge of the residue (float)` hasAtom(self, name) numAtoms(self) `Get the number of atoms for the residue Returns Number of atoms in the residue (int)` removeAtom(self, atomname) `Remove an atom from the residue object. Parameters atomname: The name of the atom to be removed (string)` renameAtom(self, oldname, newname) `Rename an atom to a new name Parameters oldname: The old atom name (string) newname: The new atom name (string)` renameResidue(self, name) `Rename a given residue Parameters name: The new name of the residue` reorder(self) `Reorder the atoms to start with N, CA, C, O if they exist` rotateTetrahedral(self, atom1, atom2, angle) `Rotate about the atom1-atom2 bond by a given angle All atoms connected to atom2 will rotate. Parameters: atom1: The first atom of the bond to rotate about (atom) atom2: The second atom of the bond to rotate about (atom) angle: The number of degrees to rotate (float)` set(self, name, value) `Set a member of the Residue class to a specific value Parameters name: The name of the object to set (string) value: The object to append Possible Values atoms: The atoms in the residue name: The name of the residue chain: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise isDirty: 1 if the residue is not missing atoms, 0 otherwise Notes resSeq points to the residue.setResSeq function Returns item: The value of the member` setChainID(self, value) `Set the chainID field to a certain value` setDonorsAndAcceptors(self) `Set the donors and acceptors within the residue` setResSeq(self, value) `Set the atom field resSeq to a certain value and change the residue's information. The icode field is no longer useful. Parameters value: The new value of resSeq (int)` update_terminus_status(self) `Update the isNterms and isCterm flags`
class RC(CYT)
`` |  | Method resolution order: RC CYT Nucleic src.structures.Residue Methods inherited from CYT: __init__(self, atoms, ref) `Initialize the class Parameters atoms: A list of Atom objects to be stored in this class (list)` letterCode(self) setState(self) `Set the state to distinguish RNA from DNA.` Methods inherited from Nucleic: addAtom(self, atom) `Override the existing addAtom - include the link to the reference object` addDihedralAngle(self, value) `Add the value to the list of chiangles Parameters value: The value to be added (float)` createAtom(self, atomname, newcoords) `Create an atom. Overrides the generic residue's createAtom(). Parameters atomname: The name of the atom to add (string) newcoords: The coordinates of the atom (list)` Methods inherited from src.structures.Residue: __str__(self) `Basic string representation` addMissing(self, value) `Add the value to the list of missing atoms Parameters value: The name of the missing atom (string)` get(self, name) `Get a member of the Residue class Parameters name: The name of the member (string) Possible Values atoms: The atoms in the residue name: The name of the residue chainID: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise missing: List of missing atoms of the residue Returns item: The value of the member` getAtom(self, name) `Retrieve an atom from the mapping Parameters resname: The name of the residue to retrieve (string)` getAtoms(self) getCharge(self) `Get the total charge of the residue. In order to get rid of floating point rounding error, do the string transformation. Returns: charge: The charge of the residue (float)` hasAtom(self, name) numAtoms(self) `Get the number of atoms for the residue Returns Number of atoms in the residue (int)` removeAtom(self, atomname) `Remove an atom from the residue object. Parameters atomname: The name of the atom to be removed (string)` renameAtom(self, oldname, newname) `Rename an atom to a new name Parameters oldname: The old atom name (string) newname: The new atom name (string)` renameResidue(self, name) `Rename a given residue Parameters name: The new name of the residue` reorder(self) `Reorder the atoms to start with N, CA, C, O if they exist` rotateTetrahedral(self, atom1, atom2, angle) `Rotate about the atom1-atom2 bond by a given angle All atoms connected to atom2 will rotate. Parameters: atom1: The first atom of the bond to rotate about (atom) atom2: The second atom of the bond to rotate about (atom) angle: The number of degrees to rotate (float)` set(self, name, value) `Set a member of the Residue class to a specific value Parameters name: The name of the object to set (string) value: The object to append Possible Values atoms: The atoms in the residue name: The name of the residue chain: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise isDirty: 1 if the residue is not missing atoms, 0 otherwise Notes resSeq points to the residue.setResSeq function Returns item: The value of the member` setChainID(self, value) `Set the chainID field to a certain value` setDonorsAndAcceptors(self) `Set the donors and acceptors within the residue` setResSeq(self, value) `Set the atom field resSeq to a certain value and change the residue's information. The icode field is no longer useful. Parameters value: The new value of resSeq (int)` update_terminus_status(self) `Update the isNterms and isCterm flags`
class RG(GUA)
`` |  | Method resolution order: RG GUA Nucleic src.structures.Residue Methods inherited from GUA: __init__(self, atoms, ref) `Initialize the class Parameters atoms: A list of Atom objects to be stored in this class (list)` letterCode(self) setState(self) `Set the state to distinguish RNA from DNA.` Methods inherited from Nucleic: addAtom(self, atom) `Override the existing addAtom - include the link to the reference object` addDihedralAngle(self, value) `Add the value to the list of chiangles Parameters value: The value to be added (float)` createAtom(self, atomname, newcoords) `Create an atom. Overrides the generic residue's createAtom(). Parameters atomname: The name of the atom to add (string) newcoords: The coordinates of the atom (list)` Methods inherited from src.structures.Residue: __str__(self) `Basic string representation` addMissing(self, value) `Add the value to the list of missing atoms Parameters value: The name of the missing atom (string)` get(self, name) `Get a member of the Residue class Parameters name: The name of the member (string) Possible Values atoms: The atoms in the residue name: The name of the residue chainID: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise missing: List of missing atoms of the residue Returns item: The value of the member` getAtom(self, name) `Retrieve an atom from the mapping Parameters resname: The name of the residue to retrieve (string)` getAtoms(self) getCharge(self) `Get the total charge of the residue. In order to get rid of floating point rounding error, do the string transformation. Returns: charge: The charge of the residue (float)` hasAtom(self, name) numAtoms(self) `Get the number of atoms for the residue Returns Number of atoms in the residue (int)` removeAtom(self, atomname) `Remove an atom from the residue object. Parameters atomname: The name of the atom to be removed (string)` renameAtom(self, oldname, newname) `Rename an atom to a new name Parameters oldname: The old atom name (string) newname: The new atom name (string)` renameResidue(self, name) `Rename a given residue Parameters name: The new name of the residue` reorder(self) `Reorder the atoms to start with N, CA, C, O if they exist` rotateTetrahedral(self, atom1, atom2, angle) `Rotate about the atom1-atom2 bond by a given angle All atoms connected to atom2 will rotate. Parameters: atom1: The first atom of the bond to rotate about (atom) atom2: The second atom of the bond to rotate about (atom) angle: The number of degrees to rotate (float)` set(self, name, value) `Set a member of the Residue class to a specific value Parameters name: The name of the object to set (string) value: The object to append Possible Values atoms: The atoms in the residue name: The name of the residue chain: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise isDirty: 1 if the residue is not missing atoms, 0 otherwise Notes resSeq points to the residue.setResSeq function Returns item: The value of the member` setChainID(self, value) `Set the chainID field to a certain value` setDonorsAndAcceptors(self) `Set the donors and acceptors within the residue` setResSeq(self, value) `Set the atom field resSeq to a certain value and change the residue's information. The icode field is no longer useful. Parameters value: The new value of resSeq (int)` update_terminus_status(self) `Update the isNterms and isCterm flags`
class RU(URA)
`` |  | Method resolution order: RU URA Nucleic src.structures.Residue Methods inherited from URA: __init__(self, atoms, ref) `Initialize the class Parameters atoms: A list of Atom objects to be stored in this class (list)` letterCode(self) setState(self) `Set the state to distinguish RNA from DNA. In this case it is always RNA.` Methods inherited from Nucleic: addAtom(self, atom) `Override the existing addAtom - include the link to the reference object` addDihedralAngle(self, value) `Add the value to the list of chiangles Parameters value: The value to be added (float)` createAtom(self, atomname, newcoords) `Create an atom. Overrides the generic residue's createAtom(). Parameters atomname: The name of the atom to add (string) newcoords: The coordinates of the atom (list)` Methods inherited from src.structures.Residue: __str__(self) `Basic string representation` addMissing(self, value) `Add the value to the list of missing atoms Parameters value: The name of the missing atom (string)` get(self, name) `Get a member of the Residue class Parameters name: The name of the member (string) Possible Values atoms: The atoms in the residue name: The name of the residue chainID: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise missing: List of missing atoms of the residue Returns item: The value of the member` getAtom(self, name) `Retrieve an atom from the mapping Parameters resname: The name of the residue to retrieve (string)` getAtoms(self) getCharge(self) `Get the total charge of the residue. In order to get rid of floating point rounding error, do the string transformation. Returns: charge: The charge of the residue (float)` hasAtom(self, name) numAtoms(self) `Get the number of atoms for the residue Returns Number of atoms in the residue (int)` removeAtom(self, atomname) `Remove an atom from the residue object. Parameters atomname: The name of the atom to be removed (string)` renameAtom(self, oldname, newname) `Rename an atom to a new name Parameters oldname: The old atom name (string) newname: The new atom name (string)` renameResidue(self, name) `Rename a given residue Parameters name: The new name of the residue` reorder(self) `Reorder the atoms to start with N, CA, C, O if they exist` rotateTetrahedral(self, atom1, atom2, angle) `Rotate about the atom1-atom2 bond by a given angle All atoms connected to atom2 will rotate. Parameters: atom1: The first atom of the bond to rotate about (atom) atom2: The second atom of the bond to rotate about (atom) angle: The number of degrees to rotate (float)` set(self, name, value) `Set a member of the Residue class to a specific value Parameters name: The name of the object to set (string) value: The object to append Possible Values atoms: The atoms in the residue name: The name of the residue chain: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise isDirty: 1 if the residue is not missing atoms, 0 otherwise Notes resSeq points to the residue.setResSeq function Returns item: The value of the member` setChainID(self, value) `Set the chainID field to a certain value` setDonorsAndAcceptors(self) `Set the donors and acceptors within the residue` setResSeq(self, value) `Set the atom field resSeq to a certain value and change the residue's information. The icode field is no longer useful. Parameters value: The new value of resSeq (int)` update_terminus_status(self) `Update the isNterms and isCterm flags`
class THY(Nucleic)
`` | `Thymine class This class gives data about the Thymine object, and inherits off the base residue class.`
| Method resolution order: THY Nucleic src.structures.Residue Methods defined here: __init__(self, atoms, ref) `Initialize the class Parameters atoms: A list of Atom objects to be stored in this class (list)` letterCode(self) setState(self) `Set the state to distinguish RNA from DNA. In this case it is always DNA.` Methods inherited from Nucleic: addAtom(self, atom) `Override the existing addAtom - include the link to the reference object` addDihedralAngle(self, value) `Add the value to the list of chiangles Parameters value: The value to be added (float)` createAtom(self, atomname, newcoords) `Create an atom. Overrides the generic residue's createAtom(). Parameters atomname: The name of the atom to add (string) newcoords: The coordinates of the atom (list)` Methods inherited from src.structures.Residue: __str__(self) `Basic string representation` addMissing(self, value) `Add the value to the list of missing atoms Parameters value: The name of the missing atom (string)` get(self, name) `Get a member of the Residue class Parameters name: The name of the member (string) Possible Values atoms: The atoms in the residue name: The name of the residue chainID: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise missing: List of missing atoms of the residue Returns item: The value of the member` getAtom(self, name) `Retrieve an atom from the mapping Parameters resname: The name of the residue to retrieve (string)` getAtoms(self) getCharge(self) `Get the total charge of the residue. In order to get rid of floating point rounding error, do the string transformation. Returns: charge: The charge of the residue (float)` hasAtom(self, name) numAtoms(self) `Get the number of atoms for the residue Returns Number of atoms in the residue (int)` removeAtom(self, atomname) `Remove an atom from the residue object. Parameters atomname: The name of the atom to be removed (string)` renameAtom(self, oldname, newname) `Rename an atom to a new name Parameters oldname: The old atom name (string) newname: The new atom name (string)` renameResidue(self, name) `Rename a given residue Parameters name: The new name of the residue` reorder(self) `Reorder the atoms to start with N, CA, C, O if they exist` rotateTetrahedral(self, atom1, atom2, angle) `Rotate about the atom1-atom2 bond by a given angle All atoms connected to atom2 will rotate. Parameters: atom1: The first atom of the bond to rotate about (atom) atom2: The second atom of the bond to rotate about (atom) angle: The number of degrees to rotate (float)` set(self, name, value) `Set a member of the Residue class to a specific value Parameters name: The name of the object to set (string) value: The object to append Possible Values atoms: The atoms in the residue name: The name of the residue chain: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise isDirty: 1 if the residue is not missing atoms, 0 otherwise Notes resSeq points to the residue.setResSeq function Returns item: The value of the member` setChainID(self, value) `Set the chainID field to a certain value` setDonorsAndAcceptors(self) `Set the donors and acceptors within the residue` setResSeq(self, value) `Set the atom field resSeq to a certain value and change the residue's information. The icode field is no longer useful. Parameters value: The new value of resSeq (int)` update_terminus_status(self) `Update the isNterms and isCterm flags`
class URA(Nucleic)
`` | `Uridine class This class gives data about the Uridine object, and inherits off the base residue class.`
| Method resolution order: URA Nucleic src.structures.Residue Methods defined here: __init__(self, atoms, ref) `Initialize the class Parameters atoms: A list of Atom objects to be stored in this class (list)` letterCode(self) setState(self) `Set the state to distinguish RNA from DNA. In this case it is always RNA.` Methods inherited from Nucleic: addAtom(self, atom) `Override the existing addAtom - include the link to the reference object` addDihedralAngle(self, value) `Add the value to the list of chiangles Parameters value: The value to be added (float)` createAtom(self, atomname, newcoords) `Create an atom. Overrides the generic residue's createAtom(). Parameters atomname: The name of the atom to add (string) newcoords: The coordinates of the atom (list)` Methods inherited from src.structures.Residue: __str__(self) `Basic string representation` addMissing(self, value) `Add the value to the list of missing atoms Parameters value: The name of the missing atom (string)` get(self, name) `Get a member of the Residue class Parameters name: The name of the member (string) Possible Values atoms: The atoms in the residue name: The name of the residue chainID: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise missing: List of missing atoms of the residue Returns item: The value of the member` getAtom(self, name) `Retrieve an atom from the mapping Parameters resname: The name of the residue to retrieve (string)` getAtoms(self) getCharge(self) `Get the total charge of the residue. In order to get rid of floating point rounding error, do the string transformation. Returns: charge: The charge of the residue (float)` hasAtom(self, name) numAtoms(self) `Get the number of atoms for the residue Returns Number of atoms in the residue (int)` removeAtom(self, atomname) `Remove an atom from the residue object. Parameters atomname: The name of the atom to be removed (string)` renameAtom(self, oldname, newname) `Rename an atom to a new name Parameters oldname: The old atom name (string) newname: The new atom name (string)` renameResidue(self, name) `Rename a given residue Parameters name: The new name of the residue` reorder(self) `Reorder the atoms to start with N, CA, C, O if they exist` rotateTetrahedral(self, atom1, atom2, angle) `Rotate about the atom1-atom2 bond by a given angle All atoms connected to atom2 will rotate. Parameters: atom1: The first atom of the bond to rotate about (atom) atom2: The second atom of the bond to rotate about (atom) angle: The number of degrees to rotate (float)` set(self, name, value) `Set a member of the Residue class to a specific value Parameters name: The name of the object to set (string) value: The object to append Possible Values atoms: The atoms in the residue name: The name of the residue chain: The chainID associated with the residue resSeq: The sequence number of the residue icode: The iCode of the residue SSbonded: 1 if the residue has a SS bond, 0 otherwise SSbondpartner: The residue of the bond partner type: The type associated with this residue isNterm: # of hydrogens if the residue is the N-Terminus, 0 otherwise isCterm: 1 if the residue is the C-Terminus, 0 otherwise isDirty: 1 if the residue is not missing atoms, 0 otherwise Notes resSeq points to the residue.setResSeq function Returns item: The value of the member` setChainID(self, value) `Set the chainID field to a certain value` setDonorsAndAcceptors(self) `Set the donors and acceptors within the residue` setResSeq(self, value) `Set the atom field resSeq to a certain value and change the residue's information. The icode field is no longer useful. Parameters value: The new value of resSeq (int)` update_terminus_status(self) `Update the isNterms and isCterm flags`

Data
`` |  | BACKBONE = ['N', 'CA', 'C', 'O', 'O2', 'HA', 'HN', 'H', 'tN'] DIHEDRAL = 57.2958 INSTALLDIR = '/Users/d3y382/pdb2pqr/' SMALL = 1e-07 TMPDIR = 'tmp/' __author__ = 'Todd Dolinsky' __date__ = '28 February 2006' lineParsers = {'ANISOU': <class 'src.pdb.ANISOU'>, 'ATOM': <class 'src.pdb.ATOM'>, 'AUTHOR': <class 'src.pdb.AUTHOR'>, 'CAVEAT': <class 'src.pdb.CAVEAT'>, 'CISPEP': <class 'src.pdb.CISPEP'>, 'COMPND': <class 'src.pdb.COMPND'>, 'CONECT': <class 'src.pdb.CONECT'>, 'CRYST1': <class 'src.pdb.CRYST1'>, 'DBREF': <class 'src.pdb.DBREF'>, 'END': <class 'src.pdb.END'>, ...}

Author
`` |  | Todd Dolinsky